/*
 * string.js - built-in string class extensions.
 *
 * Verlof Web application
 *
 * Copyright (C) 2002-2005, by Leiden University.
 * verlof is free software.  See the file Copying for copying permission.
 *
 * Author: Martin J. Moene
 *
 * $Id: $
 */

/*----------------------------------------------------------------------------
 * String - string functions to support name parsing.
 *----------------------------------------------------------------------------
 */

/*
 * String.toLeadCaps - transform string to lead capitals.
 *
 * Prefix case handled in String.toPrefixCase().
 */

String.prototype.toLeadCaps  = String_toLeadCaps;

function String_toLeadCaps()
{
//   return this.replace( /(\b\w)/g, function(s, p) { return p.toUpperCase(); } );

   var u = true;
   var mystr = '';

   for ( i = 0; i < this.length; i++ )
   {
      var c = this.charAt(i);

      mystr += u ? c.toUpperCase() : c.toLowerCase();

      u = false;

      if ( c.match( /[ ._-]/ ) )
	 u = true;
   }

   return mystr;
}

/*
 * String.toPrefixCase - transform string for prefix case.
 *
 * Special case: name contains dash Eik-van Linden (van lowercase).
 */

String.prototype.toPrefixCase = String_toPrefixCase;

function String_toPrefixCase()
{
//	re = new RegExp( '\\b' + prefixTable[i] + '\\b', 'ig' );
//	s = s.replace( re, function(s, p) { return prefixTable[i]; } );

   s = this;

   for ( var i in prefixTable )
   {
      re = new RegExp( '(\\b|_)' + prefixTable[i] + '(\\b|_)', 'ig' );

      for ( var k = 3; k; k-- )
	 s = s.replace( re, '$1' + prefixTable[i]  + '$2 ' );
   }

   return s;
}

/*
 * String.toSpace - transform underscores to spaces.
 */

String.prototype.toSpace  = String_toSpace;

function String_toSpace()
{
   return this.replace( /_/g, ' ' );
}

/*
 * String.toSingleSpace - transform multiple consecutive spaces to a single one.
 */

String.prototype.toSingleSpace	= String_toSingleSpace;

function String_toSingleSpace()
{
   return this.replace( /[ ]+/g, ' ' );
}

/*
 * String.stripSpace - strip space surrounding string.
 */

String.prototype.stripSpace = String_stripSpace;

function String_stripSpace()
{
   return this.replace( /^\s+/, "").replace( /\s+$/, "" );
}

/*
 * String.stripDash - strip trailing dash.
 */

String.prototype.stripDash = String_stripDash;

function String_stripDash()
{
   return this.replace( /[-]+$/, "" );
}

/*
 * String.stripToWord - strip space and punctuation upto next word.
 */

String.prototype.stripToWord = String_stripToWord;

function String_stripToWord()
{
   return this.replace( /^([\s.,;:_])+/, "" );
}


/*
 * String.join - Concatenate an array of words with intervening occurrences of sep.
 */

String.prototype.join = String_join;

function String_join(list, sep)
{
   s = new String();

   for ( var i = 0; i < list.length; i++ ) {
      if ( i == 0 ) s  = list[i]
      else	    s += ',' + list[i]
   }

   return s;
}


/*
 * String.mapDiacritics - map extended ASCII accented characters:
 */

String.prototype.mapDiacritics = String_mapDiacritics;

function String_mapDiacritics()
{
   var map = "CueaaaaceeeiiiAAEooouuyOU";
   var	 s = this;

   for ( var i = 0; i < map.length; i += 2 )
   {
      var re = new RegExp( map.substr(i, 1), "g" );
	   s = s.replace( re, map.substr(i + 1, 1) );
   }

   return s.replace( //, "ae" ).replace( //, "AE" );
}


/*
 * end of file
 */

